%
% FUNCTION 6.4 : "cp0602_Gaussian_PSD_nth"
%
% Generates the normalized PSD of the n-th derivative of
% the Gaussian pulse with variance sigma^2 as defined in:
% 
%          Sheng, H., P. Orlik, A.M. Haimovich, L.J. Cimini Jr.,
%          and J. Zhang, "On the Spectral and Power
%          Requirements for Ultra Wideband Transmission,"
%          IEEE International Conference on Communications,
%          Volume: 1 (May 2003), 738-742.
%
% The function receives as input:
%
% a vector representing the frequency axis 'frequency'
% the order of the derivative 'n', the square root of
% the variance 'sigma', and the peak value of the PSD 'Amax'
%
% The function returns the PSD evaluated on the frequency
% range determined by 'frequency'
% 
% Programmed by Luca De Nardis

function PSD = cp0602_Gaussian_PSD_nth(frequency, n,...
   sigma, Amax)
PSD = Amax * (1 / ((n^n) * exp(-n))) * [(2 * pi *...
   frequency * sigma) .^ (2 * n)] .* exp(-(2 * pi *...
   frequency * sigma) .^ 2);